@@ -1,3 +1,11 @@
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
 /*
  * MSNT - Microsoft Windows NT domain squid authenticator module
  * Version 2.0 by Stellar-X Pty Ltd, Antonino Iannella
@@ -33,11 +41,9 @@
 #include "rfc1738.h"
 #include "util.h"
 
-#include <stdio.h>
-#include <signal.h>
+#include <csignal>
+#include <cstring>
 #include <syslog.h>
-#include <string.h>
-#include <sys/time.h>
 
 #include "msntauth.h"
 
