@@ -1,4 +1,11 @@
 #!/bin/sh
+#
+## Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+##
+## Squid software is distributed under GPLv2+ license and includes
+## contributions from numerous individuals and organizations.
+## Please see the COPYING and CONTRIBUTORS files for details.
+##
 
 # Removes an configuration file if it is identical to the default file,
 # preventing "make distcheck" failures due to configuration leftovers.
@@ -18,7 +25,7 @@ fi
 if test -f $prime
 then
 	# is the primary config identical to the default?
-	if diff -q $default $prime > /dev/null
+	if diff $default $prime > /dev/null
 	then
  		echo " $remover -f $prime";
                 $remover -f $prime;
