@@ -1,14 +1,17 @@
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
 #include "squid.h"
 #include "ssl/certificate_db.h"
-#if HAVE_ERRNO_H
-#include <errno.h>
-#endif
-#if HAVE_FSTREAM
+
+#include <cerrno>
 #include <fstream>
-#endif
-#if HAVE_STDEXCEPT
 #include <stdexcept>
-#endif
 #if HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
