@@ -1,6 +1,13 @@
-#define SQUID_UNIT_TEST 1
-#include "squid.h"
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
 
+#include "squid.h"
+#include "ConfigParser.h"
 #include "DiskIO/DiskIOModule.h"
 #include "fs/rock/RockSwapDir.h"
 #include "globals.h"
@@ -17,12 +24,10 @@
 #include "testRock.h"
 #include "testStoreSupport.h"
 
+#include <stdexcept>
 #if HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
-#if HAVE_STDEXCEPT
-#include <stdexcept>
-#endif
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -66,9 +71,9 @@ testRock::setUp()
 
     char *path=xstrdup(TESTDIR);
 
-    char *config_line=xstrdup("foo 10 max-size=16384");
+    char *config_line=xstrdup("10 max-size=16384");
 
-    strtok(config_line, w_space);
+    ConfigParser::SetCfgLine(config_line);
 
     store->parse(0, path);
     store_maxobjsize = 1024*1024*2;
@@ -81,7 +86,7 @@ testRock::setUp()
     store->create();
 
     rr = new Rock::SwapDirRr;
-    rr->run(rrAfterConfig);
+    rr->useConfig();
 }
 
 void
@@ -95,7 +100,8 @@ testRock::tearDown()
 
     free_cachedir(&Config.cacheSwap);
 
-    delete rr;
+    rr->finishShutdown(); // deletes rr
+    rr = NULL;
 
     // TODO: do this once, or each time.
     // safe_free(Config.replPolicy->type);
@@ -116,17 +122,13 @@ testRock::commonInit()
     StoreFileSystem::SetupAllFs();
 
     Config.Store.avgObjectSize = 1024;
-
     Config.Store.objectsPerBucket = 20;
-
     Config.Store.maxObjectSize = 2048;
 
     Config.store_dir_select_algorithm = xstrdup("round-robin");
 
     Config.replPolicy = new RemovalPolicySettings;
-
-    Config.replPolicy->type = xstrdup ("lru");
-
+    Config.replPolicy->type = xstrdup("lru");
     Config.replPolicy->args = NULL;
 
     /* garh garh */
@@ -166,21 +168,27 @@ testRock::storeInit()
      */
 
     /* nothing left to rebuild */
-    CPPUNIT_ASSERT_EQUAL(1, StoreController::store_dirs_rebuilding);
+    CPPUNIT_ASSERT_EQUAL(0, StoreController::store_dirs_rebuilding);
+}
+
+static const char *
+storeId(const int i)
+{
+    static char buf[64];
+    snprintf(buf, sizeof(buf), "dummy url %i", i);
+    buf[sizeof(buf) - 1] = '\0';
+    return buf;
 }
 
 StoreEntry *
 testRock::createEntry(const int i)
 {
     RequestFlags flags;
-    flags.cachable = 1;
-    char url[64];
-    snprintf(url, sizeof(url), "dummy url %i", i);
-    url[sizeof(url) - 1] = '\0';
+    flags.cachable = true;
     StoreEntry *const pe =
-        storeCreateEntry(url, "dummy log url", flags, METHOD_GET);
+        storeCreateEntry(storeId(i), "dummy log url", flags, Http::METHOD_GET);
     HttpReply *const rep = const_cast<HttpReply *>(pe->getReply());
-    rep->setHeaders(HTTP_OK, "dummy test object", "x-squid-internal/test", 0, -1, squid_curtime + 100000);
+    rep->setHeaders(Http::scOkay, "dummy test object", "x-squid-internal/test", 0, -1, squid_curtime + 100000);
 
     pe->setPublicKey();
 
@@ -212,8 +220,7 @@ testRock::addEntry(const int i)
 StoreEntry *
 testRock::getEntry(const int i)
 {
-    StoreEntry *const pe = createEntry(i);
-    return store->get(reinterpret_cast<const cache_key *>(pe->key));
+    return storeGetPublic(storeId(i), Http::METHOD_GET);
 }
 
 void
@@ -221,7 +228,7 @@ testRock::testRockCreate()
 {
     struct stat sb;
 
-    CPPUNIT_ASSERT(::stat(TESTDIR, &sb) == 0);
+    CPPUNIT_ASSERT_EQUAL(0, ::stat(TESTDIR, &sb));
 
     /* TODO: check the size */
 
@@ -239,8 +246,8 @@ testRock::testRockSwapOut()
 
         StoreEntry *const pe = addEntry(i);
 
-        CPPUNIT_ASSERT(pe->swap_status == SWAPOUT_WRITING);
-        CPPUNIT_ASSERT(pe->swap_dirn == 0);
+        CPPUNIT_ASSERT_EQUAL(SWAPOUT_WRITING, pe->swap_status);
+        CPPUNIT_ASSERT_EQUAL(0, pe->swap_dirn);
         CPPUNIT_ASSERT(pe->swap_filen >= 0);
 
         // Rock::IoState::finishedWriting() schedules an AsyncCall
@@ -248,9 +255,9 @@ testRock::testRockSwapOut()
         StockEventLoop loop;
         loop.run();
 
-        CPPUNIT_ASSERT(pe->swap_status == SWAPOUT_DONE);
+        CPPUNIT_ASSERT_EQUAL(SWAPOUT_DONE, pe->swap_status);
 
-        pe->unlock();
+        pe->unlock("testRock::testRockSwapOut priming");
     }
 
     CPPUNIT_ASSERT_EQUAL((uint64_t)5, store->currentCount());
@@ -259,46 +266,60 @@ testRock::testRockSwapOut()
     {
         StoreEntry *const pe = addEntry(4);
 
-        CPPUNIT_ASSERT(pe->swap_status == SWAPOUT_WRITING);
-        CPPUNIT_ASSERT(pe->swap_dirn == 0);
+        CPPUNIT_ASSERT_EQUAL(SWAPOUT_WRITING, pe->swap_status);
+        CPPUNIT_ASSERT_EQUAL(0, pe->swap_dirn);
         CPPUNIT_ASSERT(pe->swap_filen >= 0);
 
         StockEventLoop loop;
         loop.run();
 
-        CPPUNIT_ASSERT(pe->swap_status == SWAPOUT_DONE);
+        CPPUNIT_ASSERT_EQUAL(SWAPOUT_DONE, pe->swap_status);
+
+        pe->unlock("testRock::testRockSwapOut e#4");
     }
 
     // try to swap out entry to a used locked slot
     {
         StoreEntry *const pe = addEntry(5);
 
-        CPPUNIT_ASSERT(pe->swap_status == SWAPOUT_WRITING);
-        CPPUNIT_ASSERT(pe->swap_dirn == 0);
+        CPPUNIT_ASSERT_EQUAL(SWAPOUT_WRITING, pe->swap_status);
+        CPPUNIT_ASSERT_EQUAL(0, pe->swap_dirn);
         CPPUNIT_ASSERT(pe->swap_filen >= 0);
 
         // the slot is locked here because the async calls have not run yet
         StoreEntry *const pe2 = addEntry(5);
-        CPPUNIT_ASSERT(pe2->swap_status == SWAPOUT_NONE);
-        CPPUNIT_ASSERT(pe2->mem_obj->swapout.decision ==
-                       MemObject::SwapOut::swImpossible);
-        CPPUNIT_ASSERT(pe2->swap_dirn == -1);
-        CPPUNIT_ASSERT(pe2->swap_filen == -1);
+        CPPUNIT_ASSERT_EQUAL(SWAPOUT_NONE, pe2->swap_status);
+        CPPUNIT_ASSERT_EQUAL(MemObject::SwapOut::swImpossible, pe2->mem_obj->swapout.decision);
+        CPPUNIT_ASSERT_EQUAL(-1, pe2->swap_dirn);
+        CPPUNIT_ASSERT_EQUAL(-1, pe2->swap_filen);
 
         StockEventLoop loop;
         loop.run();
+
+        pe->unlock("testRock::testRockSwapOut e#5.1");
+        pe2->unlock("testRock::testRockSwapOut e#5.2");
+
+        // pe2 has the same public key as pe so it marks old pe for release
+        // here, we add another entry #5 into the now-available slot
+        StoreEntry *const pe3 = addEntry(5);
+        CPPUNIT_ASSERT_EQUAL(SWAPOUT_WRITING, pe3->swap_status);
+        CPPUNIT_ASSERT_EQUAL(0, pe3->swap_dirn);
+        CPPUNIT_ASSERT(pe3->swap_filen >= 0);
+        loop.run();
+        CPPUNIT_ASSERT_EQUAL(SWAPOUT_DONE, pe3->swap_status);
+        pe3->unlock("testRock::testRockSwapOut e#5.3");
     }
 
     CPPUNIT_ASSERT_EQUAL((uint64_t)6, store->currentCount());
 
-    // try to get and unlink entries
+    // try to get and release all entries
     for (int i = 0; i < 6; ++i) {
         StoreEntry *const pe = getEntry(i);
         CPPUNIT_ASSERT(pe != NULL);
 
-        pe->unlink();
+        pe->release(); // destroys pe
 
         StoreEntry *const pe2 = getEntry(i);
-        CPPUNIT_ASSERT(pe2 == NULL);
+        CPPUNIT_ASSERT_EQUAL(static_cast<StoreEntry *>(NULL), pe2);
     }
 }
